hush

package module
v0.1.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: Apache-2.0 Imports: 25 Imported by: 0

README

hush CI Coverage Status

A simple Bourne-like shell, compatible with Wasm. Written in Go.

Getting started

Install like any other go library:

go install github.com/btwiuse/hush/cmd/hush@latest

Alternatively, import hush in your own projects:

package main

import (
    "os"
    "github.com/btwiuse/hush"
)

func main() {
    exitCode := hush.Run()
    os.Exit(exitCode)
}

Wasm compatibility

Today, Go's Web Assembly support does not include running processes. To make this possible, Hush is built with hackpad's go fork. The fork contains patches that spawn and manage processes using Node.js's APIs, similar to the Node.js file system API used upstream.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run() int

Run runs the hush shell

Types

This section is empty.

Directories

Path Synopsis
cmd
hush command

Jump to